@@ -1,6 +1,6 @@
 from json import dumps, loads
 from re import findall, sub
-from typing import Any, Iterable, List, Match, NoReturn, Union, cast
+from typing import Any, Callable, Iterable, List, Match, NoReturn, Union, cast
 from warnings import warn_explicit
 
 from .hints import Replicator, Skill, SkillCode, Symbol
@@ -81,15 +81,20 @@ def _not_implemented(string: str) -> Replicator:
     return inner
 
 
-def build_skill_path(components: Iterable[Union[str, int]]) -> SkillCode:
+CaseSwitcher = Callable[[str], str]
+
+
+def build_skill_path(
+    components: Iterable[Union[str, int]], case_switcher: CaseSwitcher = snake_to_camel
+) -> SkillCode:
     it = iter(components)
-    path = snake_to_camel(str(next(it)))
+    path = case_switcher(str(next(it)))
 
     for component in it:
         if isinstance(component, int):
             path = f'(nth {component} {path})'
         else:
-            path = f'{path}->{snake_to_camel(component)}'
+            path = f'{path}->{case_switcher(component)}'
 
     return SkillCode(path)
 
@@ -135,8 +140,10 @@ class Translator:
         return [camel_to_snake(attr) for attr in cast(List[str], attributes)]
 
     @staticmethod
-    def encode_getattr(obj: SkillCode, key: str) -> SkillCode:
-        return build_skill_path([obj, key])
+    def encode_getattr(
+        obj: SkillCode, key: str, case_switcher: CaseSwitcher = snake_to_camel
+    ) -> SkillCode:
+        return build_skill_path([obj, key], case_switcher)
 
     @staticmethod
     def encode_globals(prefix: str) -> SkillCode:
@@ -170,8 +177,10 @@ class Translator:
         return loads(help_)  # type: ignore
 
     @staticmethod
-    def encode_setattr(obj: SkillCode, key: str, value: Any) -> SkillCode:
-        code = build_skill_path([obj, key])
+    def encode_setattr(
+        obj: SkillCode, key: str, value: Any, case_switcher: CaseSwitcher = snake_to_camel
+    ) -> SkillCode:
+        code = build_skill_path([obj, key], case_switcher)
         value = python_value_to_skill(value)
         return SkillCode(f'{code} = {value}')
 
